From ae866e800f20ed6bcb95ecbdf12ce37d322f4a68 Mon Sep 17 00:00:00 2001
From: "Craig R. Hughes" <craig.git@rungie.com>
Date: Sat, 1 Sep 2012 23:56:09 -0700
Subject: [PATCH] Renumber Mark of the Wild for MoP

---
 LibStatLogic-1.2/LibStatLogic-1.2.lua | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/LibStatLogic-1.2/LibStatLogic-1.2.lua b/LibStatLogic-1.2/LibStatLogic-1.2.lua
index f54afb3..26c1606 100644
--- a/LibStatLogic-1.2/LibStatLogic-1.2.lua
+++ b/LibStatLogic-1.2/LibStatLogic-1.2.lua
@@ -3582,7 +3582,7 @@ elseif playerClass == "WARLOCK" then
         ["rank"] = {
           0.05,
         }, -- BoK, MotW, EotSS
-        ["condition"] = "UnitBuff('pet', GetSpellInfo(20217)) or UnitBuff('pet', GetSpellInfo(79061)) or UnitBuff('pet', GetSpellInfo(90363))",
+        ["condition"] = "UnitBuff('pet', GetSpellInfo(20217)) or UnitBuff('pet', GetSpellInfo(1126)) or UnitBuff('pet', GetSpellInfo(90363))",
       },
     },
     ["ADD_PET_INT_MOD_INT"] = {
@@ -3596,7 +3596,7 @@ elseif playerClass == "WARLOCK" then
         ["rank"] = {
           0.05,
         }, -- BoK, MotW, EotSS
-        ["condition"] = "UnitBuff('pet', GetSpellInfo(20217)) or UnitBuff('pet', GetSpellInfo(79061)) or UnitBuff('pet', GetSpellInfo(90363))",
+        ["condition"] = "UnitBuff('pet', GetSpellInfo(20217)) or UnitBuff('pet', GetSpellInfo(1126)) or UnitBuff('pet', GetSpellInfo(90363))",
       },
     },
     -- Warlock: Soul Link - Buff: 25228
@@ -4317,7 +4317,7 @@ end
     },
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Druid: Mark of the Wild - Buff: 79061
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
@@ -4335,7 +4335,7 @@ end
         ["rank"] = {
           0.05,
         },
-        ["buff"] = 79061,        -- ["Mark of the Wild"],
+        ["buff"] = 1126,        -- ["Mark of the Wild"],
         ["group"] = D["Stat Multiplier"],
       },
       {-- Embrace of the Shale Spider
@@ -4355,7 +4355,7 @@ end
     },
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Druid: Mark of the Wild - Buff: 79061
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
@@ -4373,7 +4373,7 @@ end
         ["rank"] = {
           0.05,
         },
-        ["buff"] = 79061,        -- ["Mark of the Wild"],
+        ["buff"] = 1126,        -- ["Mark of the Wild"],
         ["group"] = D["Stat Multiplier"],
       },
       {-- Embrace of the Shale Spider
@@ -4393,7 +4393,7 @@ end
     },
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Druid: Mark of the Wild - Buff: 79061
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
@@ -4411,7 +4411,7 @@ end
         ["rank"] = {
           0.05,
         },
-        ["buff"] = 79061,        -- ["Mark of the Wild"],
+        ["buff"] = 1126,        -- ["Mark of the Wild"],
         ["group"] = D["Stat Multiplier"],
       },
       {-- Embrace of the Shale Spider
@@ -4478,7 +4478,7 @@ end
       
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Druid: Mark of the Wild - Buff: 79061
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
@@ -4496,7 +4496,7 @@ end
         ["rank"] = {
           0.05,
         },
-        ["buff"] = 79061,        -- ["Mark of the Wild"],
+        ["buff"] = 1126,        -- ["Mark of the Wild"],
         ["group"] = D["Stat Multiplier"],
       },
       {-- Embrace of the Shale Spider
@@ -4317,7 +4317,7 @@ end
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
-    -- Druid: Mark of the Wild - Buff: 79061
+    -- Druid: Mark of the Wild - Buff: 1126
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
@@ -4355,7 +4355,7 @@ end
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
-    -- Druid: Mark of the Wild - Buff: 79061
+    -- Druid: Mark of the Wild - Buff: 1126
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
@@ -4393,7 +4393,7 @@ end
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
-    -- Druid: Mark of the Wild - Buff: 79061
+    -- Druid: Mark of the Wild - Buff: 1126
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
@@ -4478,7 +4478,7 @@ end
     -- Paladin: Blessing of Kings - Buff: 20217
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
-    -- Druid: Mark of the Wild - Buff: 79061
+    -- Druid: Mark of the Wild - Buff: 1126
     -- 4.0.1: Strength, Agility, Stamina, and Intellect increased by 5%.
     -- Hunter: Embrace of the Shale Spider - Buff: 90363
-- 
1.7.11.5

